@@ -25,6 +25,7 @@ from gi.repository import GLib
 import gtweak.utils
 from gtweak.gsettings import GSettingsSetting
 
+
 class _ShellProxy:
     def __init__(self):
         d = Gio.bus_get_sync(Gio.BusType.SESSION, None)
@@ -36,7 +37,7 @@ class _ShellProxy:
                             'org.gnome.Shell',
                             None)
 
-        #GNOME Shell > 3.5 added a separate extension interface
+        # GNOME Shell > 3.5 added a separate extension interface
         self.proxy_extensions = Gio.DBusProxy.new_sync(
                             d, 0, None,
                             'org.gnome.Shell',
@@ -44,7 +45,7 @@ class _ShellProxy:
                             'org.gnome.Shell.Extensions',
                             None)
 
-        #GNOME Shell > 3.7.2 added the Mode to the DBus API
+        # GNOME Shell > 3.7.2 added the Mode to the DBus API
         val = self.proxy.get_cached_property("Mode")
         if val is not None:
             self._mode = val.unpack()
@@ -57,7 +58,7 @@ class _ShellProxy:
                 logging.warning("Error getting shell mode via Eval JS")
                 self._mode = "user"
 
-        #GNOME Shell > 3.3 added the Version to the DBus API and disabled execute_js
+        # GNOME Shell > 3.3 added the Version to the DBus API and disabled execute_js
         val = self.proxy.get_cached_property("ShellVersion")
         if val is not None:
             self._version = val.unpack()
@@ -78,6 +79,7 @@ class _ShellProxy:
     def version(self):
         return self._version
 
+
 class GnomeShell:
 
     EXTENSION_STATE = {
@@ -127,7 +129,6 @@ class GnomeShell:
 class GnomeShell32(GnomeShell):
 
     EXTENSION_ENABLED_KEY = "enabled-extensions"
-    EXTENSION_NEED_RESTART = False
     SUPPORTS_EXTENSION_PREFS = False
 
     def list_extensions(self):
@@ -156,6 +157,7 @@ class GnomeShell34(GnomeShell32):
     def uninstall_extension(self, uuid):
         return self._proxy.proxy.UninstallExtension('(s)', uuid)
 
+
 class GnomeShell36(GnomeShell34):
 
     def list_extensions(self):
@@ -164,20 +166,26 @@ class GnomeShell36(GnomeShell34):
     def uninstall_extension(self, uuid):
         return self._proxy.proxy_extensions.UninstallExtension('(s)', uuid)
 
+    def install_remote_extension(self, uuid, reply_handler, error_handler, user_data):
+        self._proxy.proxy_extensions.InstallRemoteExtension('(s)', uuid,
+            result_handler=reply_handler, error_handler=error_handler, user_data=user_data)
+
+
 @gtweak.utils.singleton
 class GnomeShellFactory:
     def __init__(self):
         try:
             proxy = _ShellProxy()
             settings = GSettingsSetting("org.gnome.shell")
-            v = map(int,proxy.version.split("."))
+            v = list(map(int, proxy.version.split(".")))
 
-            if v >= [3,5,0]:
+            if v >= [3, 5, 0]:
                 self.shell = GnomeShell36(proxy, settings)
             elif v >= [3,3,2]:
                 self.shell = GnomeShell34(proxy, settings)
             elif v >= [3,1,4]:
                 self.shell = GnomeShell32(proxy, settings)
+
             else:
                 logging.warn("Shell version not supported")
                 self.shell = None
@@ -196,7 +204,7 @@ if __name__ == "__main__":
     logging.basicConfig(format="%(levelname)-8s: %(message)s", level=logging.DEBUG)
 
     s = GnomeShellFactory().get_shell()
-    print "Shell Version: %s" % s.version
-    print s.list_extensions()
+    print("Shell Version: %s" % s.version)
+    print(s.list_extensions())
 
-    print s == GnomeShellFactory().get_shell()
+    print(s == GnomeShellFactory().get_shell())
